Jpeg2000Reader

Struct Jpeg2000Reader 

pub struct Jpeg2000Reader<R> { /* private fields */ }
JPEG2000 reader

Implementations

Source

impl<R: Read + Seek> Jpeg2000Reader<R>

pub fn new(reader: R) -> Result<Self>

Create new JPEG2000 reader

pub fn set_resilience_mode(&mut self, mode: ResilienceMode)

Set error resilience mode

pub fn resilience_mode(&self) -> ResilienceMode

Get current error resilience mode

pub fn enable_error_resilience(&mut self)

Enable basic error resilience

pub fn enable_full_error_resilience(&mut self)

Enable full error resilience with aggressive recovery

pub fn disable_error_resilience(&mut self)

Disable error resilience

pub fn parse_headers(&mut self) -> Result<()>

Parse file headers

pub fn width(&self) -> Result<u32>

Get image width

pub fn height(&self) -> Result<u32>

Get image height

pub fn num_components(&self) -> Result<u16>

Get number of components

pub fn metadata(&self) -> Option<&Jp2Metadata>

Get metadata

pub fn decode_rgb(&mut self) -> Result<Vec<u8>>

Decode image to RGB

pub fn decode_rgba(&mut self) -> Result<Vec<u8>>

Decode image to RGBA

pub fn decode_tile(&mut self, tile_x: u32, tile_y: u32) -> Result<Vec<u8>>

Decode specific tile

pub fn info(&self) -> Result<ImageInfo>

Get information about the image

pub fn file_type(&self) -> Option<&FileType>

Get file type information (JP2 format only)

pub fn image_header(&self) -> Option<&ImageHeader>

Get image header information

pub fn color_specification(&self) -> Option<&ColorSpecification>

Get color specification

pub fn capture_resolution(&self) -> Option<&Resolution>

Get capture resolution (if present)

pub fn display_resolution(&self) -> Option<&Resolution>

Get display resolution (if present)

pub fn capture_resolution_dpi(&self) -> Option<(f64, f64)>

Get capture resolution in DPI (if present)

pub fn display_resolution_dpi(&self) -> Option<(f64, f64)>

Get display resolution in DPI (if present)

pub fn xml_metadata(&self) -> Vec<&XmlMetadata>

Get XML metadata boxes

pub fn uuid_boxes(&self) -> Vec<&UuidBox>

Get UUID boxes

pub fn coding_style(&self) -> Option<&CodingStyle>

Get coding style information

pub fn quantization(&self) -> Option<&Quantization>

Get quantization information

pub fn image_size_info(&self) -> Option<&ImageSize>

Get image size information from codestream

pub fn uses_mct(&self) -> bool

Check if image uses multiple component transform (MCT)

pub fn num_quality_layers(&self) -> u16

Get number of quality layers

pub fn num_decomposition_levels(&self) -> u8

Get number of decomposition levels

pub fn decode_quality_layers(&mut self, max_layer: u16) -> Result<Vec<u8>>

Decode image progressively up to specified quality layer

This method allows decoding only the first N quality layers, enabling faster decoding at lower quality levels. Quality layers are ordered from lowest (0) to highest quality.

Arguments
  • max_layer - Maximum quality layer to decode (0-based index)
Returns

RGB image data decoded up to the specified quality layer

pub fn decode_progressive(&mut self) -> Result<ProgressiveDecoder<'_, R>>

Decode image progressively with automatic layer progression

Returns an iterator that yields increasingly refined versions of the image, one for each quality layer.

pub fn progressive_layer(&self) -> Option<u16>

Get current progressive decoding state

pub fn reset_progressive_state(&mut self)

Reset progressive decoding state

pub fn is_progressive_active(&self) -> bool

Check if progressive decoding is in progress

pub fn decode_region( &mut self, x: u32, y: u32, width: u32, height: u32, ) -> Result<Vec<u8>>

Decode a specific region of interest (ROI) from the image

This method decodes only the specified rectangular region, which can be more efficient than decoding the entire image when only a portion is needed.

Arguments
  • x - Left coordinate of the region (pixels)
  • y - Top coordinate of the region (pixels)
  • width - Width of the region (pixels)
  • height - Height of the region (pixels)
Returns

RGB image data for the specified region

pub fn decode_region_at_resolution( &mut self, x: u32, y: u32, width: u32, height: u32, resolution_level: u8, ) -> Result<Vec<u8>>

Decode a region at a specific resolution level

JPEG2000 supports multi-resolution decoding through wavelet decomposition levels. Resolution level 0 is the full resolution, level 1 is half resolution, etc.

Arguments
  • x - Left coordinate at target resolution (pixels)
  • y - Top coordinate at target resolution (pixels)
  • width - Width at target resolution (pixels)
  • height - Height at target resolution (pixels)
  • resolution_level - Resolution level (0 = full, 1 = half, 2 = quarter, etc.)
Returns

RGB image data for the specified region at the specified resolution

pub fn decode_region_from_tiles( &mut self, tiles: &[(u32, u32)], region_x: u32, region_y: u32, region_width: u32, region_height: u32, ) -> Result<Vec<u8>>

Decode region using tile indices

This is a lower-level method that decodes a region by specifying the exact tiles to decode.